@@ -26,6 +26,7 @@ backends = {
     "qt": "Qt5Agg",
     "osx": "MacOSX",
     "nbagg": "nbAgg",
+    "webagg": "WebAgg",
     "notebook": "nbAgg",
     "agg": "agg",
     "svg": "svg",
@@ -119,7 +120,7 @@ def print_figure(fig, fmt="png", bbox_inches="tight", base64=False, **kwargs):
     If `base64` is True, return base64-encoded str instead of raw bytes
     for binary-encoded image formats
 
-    .. versionadded: 7.29
+    .. versionadded:: 7.29
         base64 argument
     """
     # When there's an empty figure, we shouldn't return anything, otherwise we
@@ -162,7 +163,7 @@ def retina_figure(fig, base64=False, **kwargs):
     If `base64` is True, return base64-encoded str instead of raw bytes
     for binary-encoded image formats
 
-    .. versionadded: 7.29
+    .. versionadded:: 7.29
         base64 argument
     """
     pngdata = print_figure(fig, fmt="retina", base64=False, **kwargs)
@@ -185,8 +186,8 @@ def mpl_runner(safe_execfile):
     Parameters
     ----------
     safe_execfile : function
-      This must be a function with the same interface as the
-      :meth:`safe_execfile` method of IPython.
+        This must be a function with the same interface as the
+        :meth:`safe_execfile` method of IPython.
 
     Returns
     -------
@@ -231,8 +232,8 @@ def _reshow_nbagg_figure(fig):
     """reshow an nbagg figure"""
     try:
         reshow = fig.canvas.manager.reshow
-    except AttributeError:
-        raise NotImplementedError()
+    except AttributeError as e:
+        raise NotImplementedError() from e
     else:
         reshow()
 
@@ -241,7 +242,7 @@ def select_figure_formats(shell, formats, **kwargs):
     """Select figure formats for the inline backend.
 
     Parameters
-    ==========
+    ----------
     shell : InteractiveShell
         The main IPython instance.
     formats : str or set
@@ -391,7 +392,7 @@ def import_pylab(user_ns, import_all=True):
 
     # IPython symbols to add
     user_ns['figsize'] = figsize
-    from IPython.core.display import display
+    from IPython.display import display
     # Add display and getfigs to the user's namespace
     user_ns['display'] = display
     user_ns['getfigs'] = getfigs
@@ -399,7 +400,7 @@ def import_pylab(user_ns, import_all=True):
 
 def configure_inline_support(shell, backend):
     """
-    .. deprecated: 7.23
+    .. deprecated:: 7.23
 
         use `matplotlib_inline.backend_inline.configure_inline_support()`
 
@@ -408,7 +409,6 @@ def configure_inline_support(shell, backend):
     Parameters
     ----------
     shell : InteractiveShell instance
-
     backend : matplotlib backend
     """
     warnings.warn(
@@ -418,6 +418,8 @@ def configure_inline_support(shell, backend):
         stacklevel=2,
     )
 
-    from matplotlib_inline.backend_inline import configure_inline_support as configure_inline_support_orig
+    from matplotlib_inline.backend_inline import (
+        configure_inline_support as configure_inline_support_orig,
+    )
 
     configure_inline_support_orig(shell, backend)
